Module msg

Base messages required for all vaults.

Structs

Amount
This struct represents amount of assets.
AssetsResponse
The response to the Assets query. This is just a wrapper around Uint128, so that the schema can be generated.
ConvertToAssetsResponse
The response to the ConvertToAssets query. This is just a wrapper around Uint128, so that the schema can be generated.
ConvertToSharesResponse
The response to the ConvertToShares query. This is just a wrapper around Uint128, so that the schema can be generated.
QueuedWithdrawalResponse
The response to the QueuedWithdrawal query. This is just a wrapper around QueuedWithdrawalInfo, so that the schema can be generated.
Recipient
This struct is used to represent a recipient for RedeemWithdrawalTo.
RecipientAmount
This struct is used to represent the recipient and amount fields together.
SharesResponse
The response to the Shares query. This is just a wrapper around Uint128, so that the schema can be generated.
TotalAssetsResponse
The response to the TotalAssets query. This is just a wrapper around Uint128, so that the schema can be generated.
TotalSharesResponse
The response to the TotalShares query. This is just a wrapper around Uint128, so that the schema can be generated.
VaultInfoResponse

Enums

AssetType
VaultExecuteMsg
Vault ExecuteMsg, to be implemented by the vault contract. Callable by any sender, redeemable by any recipient. The sender can be the same as the recipient in some cases.
VaultQueryMsg