pub enum VaultQueryMsg {
Shares {
staker: String,
},
Assets {
staker: String,
},
ConvertToAssets {
shares: Uint128,
},
ConvertToShares {
assets: Uint128,
},
TotalShares {},
TotalAssets {},
QueuedWithdrawal {
controller: String,
},
VaultInfo {},
}Variants
QueryMsg Shares: get the shares of a staker.
Assets
QueryMsg Assets: get the assets of a staker, converted from shares.
ConvertToAssets
QueryMsg ConvertToAssets: convert shares to assets.
Fields
QueryMsg ConvertToShares: convert assets to shares.
QueryMsg TotalShares: get the total shares in circulation.
TotalAssets
QueryMsg TotalAssets: get the total assets under vault.
QueuedWithdrawal
QueryMsg QueuedWithdrawal: get the queued withdrawal and unlock timestamp under vault.
VaultInfo
QueryMsg VaultInfo: get the vault information.