pub struct QueueWithdrawalToParams {
pub controller: Addr,
pub owner: Addr,
pub amount: Uint128,
}Expand description
This struct is used to represent the controller and amount fields together.
Fields
controller: Addrthe controller is the address that can redeem the withdrawal after the lock period
owner: Addrthe owner is the address that owns the shares being withdrawn
amount: Uint128the amount is the amount of shares to be withdrawn
Implementations