Struct TotalShares

pub struct TotalShares(/* private fields */);
This struct wraps the VirtualOffset struct with [TOTAL_SHARES] storage features checked_add_shares and checked_sub_shares implemented. Other methods are mapped to the underlying VirtualOffset instance.

TotalShares is only used to account for the total shares (and total assets). Individual staker shares are stored here to allow for different staking strategies (e.g., Tokenized Vault).

Implementations

Source

impl TotalShares

pub fn load(deps: &Deps<'_>, total_assets: Uint128) -> StdResult<Self>

Load the virtual total shares from storage (supports rebasing, by default). A fixed [OFFSET] of 1 will be added to both total shares and total assets to mitigate against inflation attack. Use [shares_to_assets] and [assets_to_shares] to convert between shares and assets.

pub fn shares_to_assets(&self, shares: Uint128) -> StdResult<Uint128>

Shares to underlying assets

pub fn assets_to_shares(&self, assets: Uint128) -> StdResult<Uint128>

Underlying assets to shares

pub fn total_shares(&self) -> Uint128

Get the total shares in circulation

pub fn total_assets(&self) -> Uint128

Get the total assets under management

pub fn checked_add_shares( &mut self, storage: &mut dyn Storage, shares: Uint128, ) -> Result<(), VaultError>

Add the new shares to the total shares and refresh the virtual shares and virtual assets. This method is checked:

  • New shares cannot be zero.
  • Total shares cannot overflow.
  • Virtual shares cannot overflow.
pub fn checked_sub_shares( &mut self, storage: &mut dyn Storage, shares: Uint128, ) -> Result<(), VaultError>

Subtract the shares from the total shares and refresh the virtual shares and virtual assets.