pub struct VirtualOffset { /* private fields */ }Expand description
Follows the OpenZeppelin’s ERC4626 mitigation strategy for inflation attack. Using a “virtual” offset to +1 to both total shares and assets representing the virtual total shares and virtual total assets. A donation of 1 and under will be completely captured by the vault—without affecting the user. A donation greater than 1, the attacker will suffer loss greater than the user. [https://github.com/OpenZeppelin/openzeppelin-contracts/blob/fa995ef1fe66e1447783cb6038470aba23a6343f/contracts/token/ERC20/extensions/ERC4626.sol#L30-L37]
Implementations
Sourceimpl VirtualOffset
impl VirtualOffset
Sourcepub fn new(total_shares: Uint128, total_assets: Uint128) -> StdResult<Self>
pub fn new(total_shares: Uint128, total_assets: Uint128) -> StdResult<Self>
Create a new VirtualOffset with the given total shares and total assets.
Shares to underlying assets
Underlying assets to shares
Get the total shares in circulation
Sourcepub fn total_assets(&self) -> Uint128
pub fn total_assets(&self) -> Uint128
Get the total assets under management