Base messages required for all vaults.
Structs
- Amount
- This struct represents amount of assets.
- Assets
Response - The response to the
Assetsquery. This is just a wrapper aroundUint128, so that the schema can be generated. - Convert
ToAssets Response - The response to the
ConvertToAssetsquery. This is just a wrapper aroundUint128, so that the schema can be generated. - Convert
ToShares Response - The response to the
ConvertToSharesquery. This is just a wrapper aroundUint128, so that the schema can be generated. - Queued
Withdrawal Response - The response to the
QueuedWithdrawalquery. This is just a wrapper aroundQueuedWithdrawalInfo, so that the schema can be generated. - Recipient
- This struct is used to represent a recipient for RedeemWithdrawalTo.
- Recipient
Amount - This struct is used to represent the recipient and amount fields together.
- Shares
Response - The response to the
Sharesquery. This is just a wrapper aroundUint128, so that the schema can be generated. - Total
Assets Response - The response to the
TotalAssetsquery. This is just a wrapper aroundUint128, so that the schema can be generated. - Total
Shares Response - The response to the
TotalSharesquery. This is just a wrapper aroundUint128, so that the schema can be generated. - Vault
Info Response
Enums
- Asset
Type - Vault
Execute Msg - Vault
ExecuteMsg, to be implemented by the vault contract. Callable by anysender, redeemable by anyrecipient. Thesendercan be the same as therecipientin some cases. - Vault
Query Msg