pub struct TotalShares(/* private fields */);Expand description
This struct wraps the VirtualOffset struct with [TOTAL_SHARES] storage features
checked_add_shares and checked_sub_shares implemented.
Other methods are mapped to the underlying VirtualOffset instance.
TotalShares is only used to account for the total shares (and total assets). Individual staker shares are stored here to allow for different staking strategies (e.g., Tokenized Vault).
Implementations
Sourcepub fn load(deps: &Deps<'_>, total_assets: Uint128) -> StdResult<Self>
pub fn load(deps: &Deps<'_>, total_assets: Uint128) -> StdResult<Self>
Load the virtual total shares from storage (supports rebasing, by default).
A fixed [OFFSET] of 1 will be added to both total shares and total assets
to mitigate against inflation attack.
Use [shares_to_assets] and [assets_to_shares] to convert between shares and assets.
Shares to underlying assets
Underlying assets to shares
Get the total shares in circulation
Sourcepub fn total_assets(&self) -> Uint128
pub fn total_assets(&self) -> Uint128
Get the total assets under management
Add the new shares to the total shares and refresh the virtual shares and virtual assets. This method is checked:
- New shares cannot be zero.
- Total shares cannot overflow.
- Virtual shares cannot overflow.
Subtract the shares from the total shares and refresh the virtual shares and virtual assets.